@@ -5,7 +5,7 @@ Client model for krema.
 from dataclasses import dataclass
 from typing import Union
 
-import kollektor
+from unikorn import kollektor
 from ..utils import dict_to_query, image_to_data_uri
 
 
